function varargout=Model14(varargin)
% Beschrijft een model voor de grondwaterstroming of voor de
% verspreiding van een verontreiniging in het grondwater.
% Model:
%   -d_x a d_x phi - d_y b d_y phi + d_x(u phi) + d_y(v phi)+c psi=f op [0,X0]x[0,y0]
%   -mu (a d_x phi, b d_y phi).n +(1-mu) phi = psi op de rand van [0,X0]x[0,y0] 
%
% De laatste input variabele moet een "string" zijn.
% De waarde van de string bepaalt wat de output is en hoeveel andere
% input variablelen er gegeven moeten zijn (dat kunnen er 0, 1, .. zijn).
% 
%[X0,Y0] = Model14('gebied')
%      Het gebied waarvoor de stroming verspreiding berekend wordt is [0,X0]x[0,y0]
%
%[a,b] = Model14(x,y,'diffusie')
%      a is de diffusie coefficient voor de x-richting en b voor de y richting.
%      x en y zijn arrays van gelijke afmeting (bv x(i,j)=i*hx en y(i,j)=j*hy
%      voor i=1:nx en j=1:ny). Dan zijn a en b arrays van dezelfde afmeting
%      en is a(i,j) de waarde van a in (x(i,j),y(i,j)), evenzo voor b.
%
%[u,v] = Model14(x,y,'advectie')
%      u is de advectie coefficient voor de x-richting en v voor de y richting.
%      x en y zijn arrays van gelijke afmeting (bv x(i,j)=i*hx en y(i,j)=j*hy
%      voor i=1:nx en j=1:ny). Dan zijn u en v arrays van dezelfde afmeting
%      en is u(i,j) de waarde van u in (x(i,j),y(i,j)), evenzo voor v.
%
%c = Model14(x,y,'absorbtie')
%      c is de absorbtie coefficient.
%      x en y zijn arrays van gelijke afmeting (bv x(i,j)=i*hx en y(i,j)=j*hy
%      voor i=1:nx en j=1:ny). Dan is c een array van dezelfde afmeting
%      en is c(i,j) de waarde van c in (x(i,j),y(i,j)).
%
%f = Model14(x,y,'bronterm')
%      f is de bronterm.
%      x en y zijn arrays van gelijke afmeting (bv x(i,j)=i*hx en y(i,j)=j*hy
%      voor i=1:nx en j=1:ny). Dan is f een array van dezelfde afmeting
%      en is f(i,j) de waarde van f in (x(i,j),y(i,j)).
%
%[psiw,muw] = Model14(y,'westrand')
%      psiw is psi op de westrand, d.w.z. op 0x[0,Y0], evenzo muw is mu op deze rand.
%      als y een array is (bf y(j)=j*hy) dan zijn psiw en muw arrays van dezelfde
%      afmeting en is psiw(j) de waarde van psi in (0,y(j))
%[psio,muo] = Model14(y,'oostrand')
%[psin,mun] = Model14(y,'noordrand')
%[psiz,muz] = Model14(y,'zuidrand')
%
%pomp=Model14('pomp')
%     pomp is een k bij 3 array
%     Als bv pomp=[10,300,-7] dan staat er een pomp in punt (x,y)=(10,300)
%     die -7 m^3 water per dag op pompt.
%     Als bv pomp=[10,300,-7;200,100,-8], dan staat er ook nog een pomp in (200,100)
%     van sterkte 8 m^3 per dag
%
%rivier=Model14('rivier')
%     rivier is een k bij 4 array.
%     Als bv rivier=[A,B,C,q] dan stroomt de rivier over lijn {(x,y)| A*x+B*y=C}
%     en "verliest" de rivier q m^3 water per dag per strekkende meter rivier aan
%     het grondwater
%



string=lower(varargin{nargin});
if ~ischar(string)
  fprintf('\nWAARSCHUWING:\n de argumenten lijst moet een string bevatten\n\n')
  return
end

switch string
case 'gebied'
  %% Het gebied is [0,X0] bij [0,Y0];
  X0=3000; Y0=3000;
  
  varargout{1}=X0;
  varargout{2}=Y0;
  
case 'diffusie'
  %% a en b zijn de doorlaadbaarheidscoefficienten.
  x=varargin{1}; y=varargin{2};
  
  a=40-35*((abs(x-1650)<300)&(abs(y-2100)<900));
  b=a;
  
  varargout{1}=a;
  varargout{2}=b;

case 'advectie'
   %% (u,v)  is het stromingsveld.
   x=varargin{1}; y=varargin{2};
   
   u=sin((y-500)/300)/10; 
   v=cos((1500-x)/300)/10; 

   % vek=1 als (u,v) gedefinieerd is als een
   % vectorveld in de roosterpunten
   vek=0;

   varargout{1}=u;
   varargout{2}=v;
   varargout{3}=vek;


case 'absorbtie'
  x=varargin{1}; y=varargin{2};
  
  c=0*x;
  
  varargout{1}=c;

case 'bronterm'
  %% f is de bronterm.
  x=varargin{1}; y=varargin{2};
  
  f=0*x;
  
  varargout{1}=f;

case 'westrand'
  y=varargin{1};
  
  psiw=400*(abs(y-2000)<100);   
  muw=1-2*(abs(y-2000)<100);
  
  varargout{1}=psiw;
  varargout{2}=muw;

case 'oostrand'
  y=varargin{1};
  
  psio=200*(abs(y-500)<100);    
  muo=1-(abs(y-500)<100);
    
  varargout{1}=psio;
  varargout{2}=muo;

case 'noordrand'
  x=varargin{1};
   
  psin=0*x;   
  mun=1+0*x;
  
  varargout{1}=psin;
  varargout{2}=mun;

case 'zuidrand'
  x=varargin{1}; 
  psiz=0*x;   
  muz=1+0*x;
  
  varargout{1}=psiz;
  varargout{2}=muz;

case 'pomp'
    %% Een pomp ontrekt q kubieke meter per dag op de plek (x0,y0)
    %% (waar de pomp staat) aan het grondwater: een pomp
    %% wordt beschreven door het drietal    [x0,y0,q] 
    %% (q negatief als er gepompt wordt, q positief als er toegevoegd wordt).
    %% Een k bij 3 array beschrijft k pompen.
    pomp=[2400,1800,-4400;1550,600,-4200];
  
  varargout{1}=pomp;

case 'rivier'
    %% rivier wordt beschreven door de lijn van punten (x,y) waarvoor
    %%      alpha*x+beta*y=gamma. '
    %% De rivier voegt q kubieke meter water per dag
    %% toe aan het grondwater per strekkende meter rivier (m^3/m dag).
    %% Een rivier wordt beschreven door:  [alpha,beta,gamma,q].
    %% Een k bij 4 array beschrijft k rivieren
    rivier=[1,0.0,900,1.4;1,0.2,900,5.4];
  
    varargout{1}=rivier;
otherwise
    fprintf('\nWAARSCHUWING:\n "%s" is een onbekende grootheid\n\n',string)
    varargout{1}=[];
end

  
return
